@@ -1,11 +1,11 @@
-/* poissonbcs.h -- This file is part of Archimedes release 0.0.1.
-   Archimedes is a simulator for Submicron 2D Silicon
-   Devices. It implements the Monte Carlo method
-   for the simulation of the semiclassical Boltzmann equation for both
-   electrons and holes. It also includes the quantum effects by means 
-   of effective potential method.
+/* poissonbcs.h -- This file is part of Archimedes release 0.0.5.
+   Archimedes is a simulator for Submicron 2D Silicon/GaAs
+   Devices. It implements the Monte Carlo method and a simplified
+   MEP model for the simulation of the semiclassical Boltzmann
+   equation for both electrons and holes. It also includes the
+   quantum effects by means of effective potential method.
 
-   Copyright (C) 2004, 2005 Jean Michel Sellier <sellier@dmi.unict.it>
+   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,12 +25,12 @@
 
 // ######################################################
 // Created on 24 Mar.2004, Siracusa, J.M.Sellier
-// Last modif. : 05 Oct.2004, Siracusa, J.M.Sellier
+// Last modif. : 07 Apr.2005, Siracusa, J.M.Sellier
 // ######################################################
 
 // Boundary Conditions for the non-stationary Poisson equation
 // For more informations about this equation
-// see the manual of GNU Archimedes release 0.0.1.
+// see the manual of GNU Archimedes release 0.0.5.
 
 void
 PoissonBCs(void)
@@ -58,6 +58,20 @@ PoissonBCs(void)
        u2d[i][1][0]=EDGE[0][i][1];
      }
    }
+// Eventual lower SiO2 interface
+// ###
+   if(SIO2_DOWN_FLAG==1)
+   {
+    int sio2nx=(int)(fabs(SIO2_INI[1]-SIO2_FIN[1])/dx);
+    int sio2ny=(int)(SIO2_THICKNESS[1]/dy);
+    if(sio2nx==0) sio2nx++;
+    if(sio2ny==0) sio2ny++;
+    for(i=1;i<=sio2nx+1;i++){
+       u2d[i+(int)(SIO2_INI[1]/dy)][0][0]=SIO2[1][i][sio2ny+2];
+       u2d[i+(int)(SIO2_INI[1]/dy)][1][0]=SIO2[1][i][sio2ny+1];
+    }
+   }
+// ###
 // Left Edge
 // =========
    for(j=1;j<=ny+1;j++){
@@ -115,6 +129,20 @@ PoissonBCs(void)
        u2d[i][ny+2][0]=EDGE[2][i][1];
      }
   }
+// Eventual upper SiO2 interface
+// ###
+   if(SIO2_UP_FLAG==1)
+   {
+    int sio2nx=(int)(fabs(SIO2_INI[0]-SIO2_FIN[0])/dx);
+    int sio2ny=(int)(SIO2_THICKNESS[0]/dy);
+    if(sio2nx==0) sio2nx++;
+    if(sio2ny==0) sio2ny++;
+    for(i=1;i<=sio2nx+1;i++){
+       u2d[i+(int)(SIO2_INI[0]/dy)][ny+1][0]=SIO2[0][i][0];
+       u2d[i+(int)(SIO2_INI[0]/dy)][ny+2][0]=SIO2[0][i][1];
+    }
+   }
+// ###
 }
 
 // ######################################################
